@@ -14,11 +14,16 @@
 {-# LANGUAGE BangPatterns   #-}
 {-# LANGUAGE EmptyDataDecls #-}
 
-module Database.PostgreSQL.LibPQ.Internal where
+module Database.PostgreSQL.LibPQ.Internal (
+    Connection (..),
+    withConn,
+    PGconn,
+    CNoticeBuffer,
+    NoticeBuffer,
+) where
 
 import Control.Concurrent.MVar (MVar)
-import Foreign
-
+import Foreign                 (ForeignPtr, Ptr, withForeignPtr)
 
 -- | 'Connection' encapsulates a connection to the backend.
 data Connection = Conn {-# UNPACK #-} !(ForeignPtr PGconn)
